@@ -1,12 +1,13 @@
 package Fennec::FileLoader;
 BEGIN {
-  $Fennec::FileLoader::VERSION = '0.026';
+  $Fennec::FileLoader::VERSION = '0.027';
 }
 use strict;
 use warnings;
 
 require Fennec;
 use Cwd qw/cwd/;
+use Fennec::Util::PackageFinder;
 
 our $ROOT;
 
@@ -42,9 +43,7 @@ sub find_types {
 
     my @plugins;
     for my $type ( @$types ) {
-        my $plugin = "Fennec\::FileType\::$type";
-        eval "require $plugin" || die( $@ );
-        push @plugins => $plugin;
+        push @plugins => load_package( $type, 'Fennec::FileType' );
     }
 
     return $class->find_all( @plugins )
