@@ -1,6 +1,6 @@
 package Fennec::Handler::TAP;
 BEGIN {
-  $Fennec::Handler::TAP::VERSION = '0.026';
+  $Fennec::Handler::TAP::VERSION = '0.027';
 }
 use strict;
 use warnings;
@@ -231,6 +231,19 @@ sub _result_diag {
 }
 
 1;
+
+=head1 NAME
+
+Fennec::Handler::TAP - The TAP output handler
+
+=head1 DESCRIPTION
+
+This class generates the TAP output.
+
+=head1 SEE ALSO
+
+L<http://testanything.org> - TAP Specification.
+
 =head1 SYNOPSIS
 
 =head1 METHODS
