@@ -1,6 +1,6 @@
 package Fennec::TestFile;
 BEGIN {
-  $Fennec::TestFile::VERSION = '0.026';
+  $Fennec::TestFile::VERSION = '0.027';
 }
 use strict;
 use warnings;
@@ -24,6 +24,11 @@ sub fennec_meta {
     Fennec::TestFile::Meta->get( $self );
 }
 
+sub stash {
+    my $self = shift;
+    $self->fennec_meta->stash( @_ );
+}
+
 1;
 
 =head1 MANUAL
